==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/nonconformityobservation_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.nonconformityobservation_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.nonconformityobservation_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.nonconformityobservation_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link NonconformityObservation }
     * 
     * @return
     *     the new instance of {@link NonconformityObservation }
     */
    public NonconformityObservation createNonconformityObservation() {
        return new NonconformityObservation();
    }

    /**
     * Create an instance of {@link OBTrackingDetails }
     * 
     * @return
     *     the new instance of {@link OBTrackingDetails }
     */
    public OBTrackingDetails createOBTrackingDetails() {
        return new OBTrackingDetails();
    }

    /**
     * Create an instance of {@link OBWorkOrderDetails }
     * 
     * @return
     *     the new instance of {@link OBWorkOrderDetails }
     */
    public OBWorkOrderDetails createOBWorkOrderDetails() {
        return new OBWorkOrderDetails();
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/nonconformityobservation_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.nonconformityobservation_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.nonconformityobservation_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.nonconformityobservation_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link NonconformityObservation }
     * 
     */
    public NonconformityObservation createNonconformityObservation() {
        return new NonconformityObservation();
    }

    /**
     * Create an instance of {@link OBTrackingDetails }
     * 
     */
    public OBTrackingDetails createOBTrackingDetails() {
        return new OBTrackingDetails();
    }

    /**
     * Create an instance of {@link OBWorkOrderDetails }
     * 
     */
    public OBWorkOrderDetails createOBWorkOrderDetails() {
        return new OBWorkOrderDetails();
    }

}
